@@ -1,9 +1,9 @@
-from sk_transformers.transformer.datetime_transformer import (
+from sk_transformers.datetime_transformer import (
     DurationCalculatorTransformer,
     TimestampTransformer,
 )
-from sk_transformers.transformer.encoder_transformer import MeanEncoderTransformer
-from sk_transformers.transformer.generic_transformer import (
+from sk_transformers.encoder_transformer import MeanEncoderTransformer
+from sk_transformers.generic_transformer import (
     AggregateTransformer,
     ColumnDropperTransformer,
     DtypeTransformer,
@@ -14,8 +14,8 @@ from sk_transformers.transformer.generic_transformer import (
     ValueIndicatorTransformer,
     ValueReplacerTransformer,
 )
-from sk_transformers.transformer.number_transformer import MathExpressionTransformer
-from sk_transformers.transformer.string_transformer import (
+from sk_transformers.number_transformer import MathExpressionTransformer
+from sk_transformers.string_transformer import (
     EmailTransformer,
     IPAddressEncoderTransformer,
     PhoneTransformer,
